# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: users.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0busers.proto\x12\x18\x65vent_store.client.users\"\x9d\x01\n\tCreateReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.users.CreateReq.Options\x1aR\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x11\n\tfull_name\x18\x03 \x01(\t\x12\x0e\n\x06groups\x18\x04 \x03(\t\"\x0c\n\nCreateResp\"\x9d\x01\n\tUpdateReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.users.UpdateReq.Options\x1aR\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x11\n\tfull_name\x18\x03 \x01(\t\x12\x0e\n\x06groups\x18\x04 \x03(\t\"\x0c\n\nUpdateResp\"h\n\tDeleteReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.users.DeleteReq.Options\x1a\x1d\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\"\x0c\n\nDeleteResp\"h\n\tEnableReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.users.EnableReq.Options\x1a\x1d\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\"\x0c\n\nEnableResp\"j\n\nDisableReq\x12=\n\x07options\x18\x01 \x01(\x0b\x32,.event_store.client.users.DisableReq.Options\x1a\x1d\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\"\r\n\x0b\x44isableResp\"j\n\nDetailsReq\x12=\n\x07options\x18\x01 \x01(\x0b\x32,.event_store.client.users.DetailsReq.Options\x1a\x1d\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\"\xa8\x02\n\x0b\x44\x65tailsResp\x12G\n\x0cuser_details\x18\x01 \x01(\x0b\x32\x31.event_store.client.users.DetailsResp.UserDetails\x1a\xcf\x01\n\x0bUserDetails\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\x0e\n\x06groups\x18\x03 \x03(\t\x12P\n\x0clast_updated\x18\x04 \x01(\x0b\x32:.event_store.client.users.DetailsResp.UserDetails.DateTime\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x1a%\n\x08\x44\x61teTime\x12\x19\n\x11ticks_since_epoch\x18\x01 \x01(\x03\"\xa8\x01\n\x11\x43hangePasswordReq\x12\x44\n\x07options\x18\x01 \x01(\x0b\x32\x33.event_store.client.users.ChangePasswordReq.Options\x1aM\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x18\n\x10\x63urrent_password\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\"\x14\n\x12\x43hangePasswordResp\"\x8c\x01\n\x10ResetPasswordReq\x12\x43\n\x07options\x18\x01 \x01(\x0b\x32\x32.event_store.client.users.ResetPasswordReq.Options\x1a\x33\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"\x13\n\x11ResetPasswordResp2\xe4\x05\n\x05Users\x12S\n\x06\x43reate\x12#.event_store.client.users.CreateReq\x1a$.event_store.client.users.CreateResp\x12S\n\x06Update\x12#.event_store.client.users.UpdateReq\x1a$.event_store.client.users.UpdateResp\x12S\n\x06\x44\x65lete\x12#.event_store.client.users.DeleteReq\x1a$.event_store.client.users.DeleteResp\x12V\n\x07\x44isable\x12$.event_store.client.users.DisableReq\x1a%.event_store.client.users.DisableResp\x12S\n\x06\x45nable\x12#.event_store.client.users.EnableReq\x1a$.event_store.client.users.EnableResp\x12X\n\x07\x44\x65tails\x12$.event_store.client.users.DetailsReq\x1a%.event_store.client.users.DetailsResp0\x01\x12k\n\x0e\x43hangePassword\x12+.event_store.client.users.ChangePasswordReq\x1a,.event_store.client.users.ChangePasswordResp\x12h\n\rResetPassword\x12*.event_store.client.users.ResetPasswordReq\x1a+.event_store.client.users.ResetPasswordRespB%\n#com.eventstore.dbclient.proto.usersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'users_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.eventstore.dbclient.proto.users'
  _CREATEREQ._serialized_start=42
  _CREATEREQ._serialized_end=199
  _CREATEREQ_OPTIONS._serialized_start=117
  _CREATEREQ_OPTIONS._serialized_end=199
  _CREATERESP._serialized_start=201
  _CREATERESP._serialized_end=213
  _UPDATEREQ._serialized_start=216
  _UPDATEREQ._serialized_end=373
  _UPDATEREQ_OPTIONS._serialized_start=117
  _UPDATEREQ_OPTIONS._serialized_end=199
  _UPDATERESP._serialized_start=375
  _UPDATERESP._serialized_end=387
  _DELETEREQ._serialized_start=389
  _DELETEREQ._serialized_end=493
  _DELETEREQ_OPTIONS._serialized_start=117
  _DELETEREQ_OPTIONS._serialized_end=146
  _DELETERESP._serialized_start=495
  _DELETERESP._serialized_end=507
  _ENABLEREQ._serialized_start=509
  _ENABLEREQ._serialized_end=613
  _ENABLEREQ_OPTIONS._serialized_start=117
  _ENABLEREQ_OPTIONS._serialized_end=146
  _ENABLERESP._serialized_start=615
  _ENABLERESP._serialized_end=627
  _DISABLEREQ._serialized_start=629
  _DISABLEREQ._serialized_end=735
  _DISABLEREQ_OPTIONS._serialized_start=117
  _DISABLEREQ_OPTIONS._serialized_end=146
  _DISABLERESP._serialized_start=737
  _DISABLERESP._serialized_end=750
  _DETAILSREQ._serialized_start=752
  _DETAILSREQ._serialized_end=858
  _DETAILSREQ_OPTIONS._serialized_start=117
  _DETAILSREQ_OPTIONS._serialized_end=146
  _DETAILSRESP._serialized_start=861
  _DETAILSRESP._serialized_end=1157
  _DETAILSRESP_USERDETAILS._serialized_start=950
  _DETAILSRESP_USERDETAILS._serialized_end=1157
  _DETAILSRESP_USERDETAILS_DATETIME._serialized_start=1120
  _DETAILSRESP_USERDETAILS_DATETIME._serialized_end=1157
  _CHANGEPASSWORDREQ._serialized_start=1160
  _CHANGEPASSWORDREQ._serialized_end=1328
  _CHANGEPASSWORDREQ_OPTIONS._serialized_start=1251
  _CHANGEPASSWORDREQ_OPTIONS._serialized_end=1328
  _CHANGEPASSWORDRESP._serialized_start=1330
  _CHANGEPASSWORDRESP._serialized_end=1350
  _RESETPASSWORDREQ._serialized_start=1353
  _RESETPASSWORDREQ._serialized_end=1493
  _RESETPASSWORDREQ_OPTIONS._serialized_start=1442
  _RESETPASSWORDREQ_OPTIONS._serialized_end=1493
  _RESETPASSWORDRESP._serialized_start=1495
  _RESETPASSWORDRESP._serialized_end=1514
  _USERS._serialized_start=1517
  _USERS._serialized_end=2257
# @@protoc_insertion_point(module_scope)
