# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: shared.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cshared.proto\x12\x12\x65vent_store.client\x1a\x1bgoogle/protobuf/empty.proto\"\xa9\x01\n\x04UUID\x12\x39\n\nstructured\x18\x01 \x01(\x0b\x32#.event_store.client.UUID.StructuredH\x00\x12\x10\n\x06string\x18\x02 \x01(\tH\x00\x1aK\n\nStructured\x12\x1d\n\x15most_significant_bits\x18\x01 \x01(\x03\x12\x1e\n\x16least_significant_bits\x18\x02 \x01(\x03\x42\x07\n\x05value\"\x07\n\x05\x45mpty\"-\n\x10StreamIdentifier\x12\x13\n\x0bstream_name\x18\x03 \x01(\x0cJ\x04\x08\x01\x10\x03\"F\n\x11\x41llStreamPosition\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\"\xf7\x02\n\x14WrongExpectedVersion\x12!\n\x17\x63urrent_stream_revision\x18\x01 \x01(\x04H\x00\x12\x33\n\x11\x63urrent_no_stream\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\"\n\x18\x65xpected_stream_position\x18\x03 \x01(\x04H\x01\x12.\n\x0c\x65xpected_any\x18\x04 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12\x38\n\x16\x65xpected_stream_exists\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12\x34\n\x12\x65xpected_no_stream\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x42 \n\x1e\x63urrent_stream_revision_optionB!\n\x1f\x65xpected_stream_position_option\"\x0e\n\x0c\x41\x63\x63\x65ssDenied\"P\n\rStreamDeleted\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\"\t\n\x07Timeout\"\t\n\x07Unknown\"\x14\n\x12InvalidTransaction\"2\n\x19MaximumAppendSizeExceeded\x12\x15\n\rmaxAppendSize\x18\x01 \x01(\r\"\x1d\n\nBadRequest\x12\x0f\n\x07message\x18\x01 \x01(\tB&\n$com.eventstore.dbclient.proto.sharedb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'shared_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.eventstore.dbclient.proto.shared'
  _UUID._serialized_start=66
  _UUID._serialized_end=235
  _UUID_STRUCTURED._serialized_start=151
  _UUID_STRUCTURED._serialized_end=226
  _EMPTY._serialized_start=237
  _EMPTY._serialized_end=244
  _STREAMIDENTIFIER._serialized_start=246
  _STREAMIDENTIFIER._serialized_end=291
  _ALLSTREAMPOSITION._serialized_start=293
  _ALLSTREAMPOSITION._serialized_end=363
  _WRONGEXPECTEDVERSION._serialized_start=366
  _WRONGEXPECTEDVERSION._serialized_end=741
  _ACCESSDENIED._serialized_start=743
  _ACCESSDENIED._serialized_end=757
  _STREAMDELETED._serialized_start=759
  _STREAMDELETED._serialized_end=839
  _TIMEOUT._serialized_start=841
  _TIMEOUT._serialized_end=850
  _UNKNOWN._serialized_start=852
  _UNKNOWN._serialized_end=861
  _INVALIDTRANSACTION._serialized_start=863
  _INVALIDTRANSACTION._serialized_end=883
  _MAXIMUMAPPENDSIZEEXCEEDED._serialized_start=885
  _MAXIMUMAPPENDSIZEEXCEEDED._serialized_end=935
  _BADREQUEST._serialized_start=937
  _BADREQUEST._serialized_end=966
# @@protoc_insertion_point(module_scope)
