# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: serverfeatures.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import shared_pb2 as shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14serverfeatures.proto\x12\"event_store.client.server_features\x1a\x0cshared.proto\"|\n\x10SupportedMethods\x12\x44\n\x07methods\x18\x01 \x03(\x0b\x32\x33.event_store.client.server_features.SupportedMethod\x12\"\n\x1a\x65vent_store_server_version\x18\x02 \x01(\t\"N\n\x0fSupportedMethod\x12\x13\n\x0bmethod_name\x18\x01 \x01(\t\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x03 \x03(\t2x\n\x0eServerFeatures\x12\x66\n\x13GetSupportedMethods\x12\x19.event_store.client.Empty\x1a\x34.event_store.client.server_features.SupportedMethodsB.\n,com.eventstore.dbclient.proto.serverfeaturesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'serverfeatures_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,com.eventstore.dbclient.proto.serverfeatures'
  _SUPPORTEDMETHODS._serialized_start=74
  _SUPPORTEDMETHODS._serialized_end=198
  _SUPPORTEDMETHOD._serialized_start=200
  _SUPPORTEDMETHOD._serialized_end=278
  _SERVERFEATURES._serialized_start=280
  _SERVERFEATURES._serialized_end=400
# @@protoc_insertion_point(module_scope)
